==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ko.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "작업",
    "Due yesterday" : "어제 끝남",
    "Due today" : "오늘 끝남",
    "Due tomorrow" : "내일 끝남",
    "Due on" : "만료일:",
    "Started yesterday" : "어제 시작됨",
    "Starts today" : "오늘 시작됨",
    "Starts tomorrow" : "내일 시작됨",
    "Started on" : "시작일:",
    "Starts on" : "시작일:",
    "[Remind me yesterday at ]HH:mm" : "어제 HH:mm[에 알림]",
    "[Remind me today at ]HH:mm" : "오늘 HH:mm[에 알림]",
    "[Remind me tomorrow at ]HH:mm" : "내일 HH:mm[에 알림]",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "YYYY년 MMM DD일 HH:mm[에 알림]",
    "Yesterday" : "어제",
    "Today" : "오늘",
    "Tomorrow" : "내일",
    "in %s" : "%s",
    "%s ago" : "%s 전",
    "seconds" : "초",
    "a minute" : "1분",
    "%d minutes" : "%d분",
    "an hour" : "1시간",
    "%d hours" : "%d시간",
    "a day" : "1일",
    "%d days" : "%d일",
    "a month" : "1개월",
    "%d months" : "%d개월",
    "a year" : "1년",
    "%d years" : "%d년",
    "week" : "주",
    "weeks" : "주",
    "day" : "일",
    "days" : "일",
    "hour" : "시간",
    "hours" : "시간",
    "minute" : "분",
    "minutes" : "분",
    "second" : "초",
    "before beginning" : "시작 이전",
    "after beginning" : "시작 이후",
    "before end" : "종료 이전",
    "after end" : "종료 이후",
    "Comment" : "설명",
    "Add a comment" : "설명 추가",
    "This will delete the Calendar \"%s\" and all of its entries." : "달력 \"%s\" 및 포함된 모든 항목을 삭제합니다.",
    "The name \"%s\" is already used." : "이름 \"%s\"이(가) 이미 사용 중입니다.",
    "An empty name is not allowed." : "이름을 비워둘 수 없습니다.",
    "Hidden" : "숨김",
    "Visible" : "보임",
    "Automatic" : "자동",
    "Sunday" : "일요일",
    "Monday" : "월요일",
    "Tuesday" : "화요일",
    "Wednesday" : "수요일",
    "Thursday" : "목요일",
    "Friday" : "금요일",
    "Saturday" : "토요일",
    "Add an important item in \"%s\"..." : "\"%s\"에 중요한 항목 추가 중...",
    "Add an item due today in \"%s\"..." : "\"%s\"에 오늘 끝나는 항목 추가 중...",
    "Add an item in \"%s\"..." : "\"%s\"에 항목 추가 중...",
    "Add a current item in \"%s\"..." : "\"%s\"에 현재 항목 추가 중...",
    "Add a subtask to \"%s\"..." : "\"%s\"에 하위 작업 추가...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["완료된 작업 %n개"],
    "Hours" : "시간",
    "Minutes" : "분",
    "Set due date" : "만료 기한 설정",
    "%s %% completed" : "%s%% 완료됨",
    "priority %s: " : "%s 우선 순위: ",
    "high" : "높음",
    "medium" : "중간",
    "low" : "낮음",
    "no priority assigned" : "지정되지 않음",
    "Remind me" : "알림",
    "at the end" : "끝날 때",
    "at the beginning" : "시작할 때",
    "Set start date" : "시작 날짜 지점",
    "{calendar} shared by {owner}" : "{owner} 님이 공유한 달력",
    "Important" : "중요",
    "Week" : "주",
    "All" : "모두",
    "Current" : "현재",
    "Completed" : "완료됨",
    "Delete" : "삭제",
    "Cancel" : "취소",
    "Edit" : "편집",
    "Link" : "링크",
    "Download" : "다운로드",
    "Save" : "저장",
    "Add List..." : "목록 추가...",
    "New List" : "새 목록",
    "Settings" : "설정",
    "Start of week" : "주의 첫 요일",
    "Visibility of Smart Collections" : "똑똑한 모음집 표시 여부",
    "Change sort order" : "정렬 순서 변경",
    "Default" : "기본값",
    "Due date" : "마감 날짜",
    "Start date" : "시작 날짜",
    "Priority" : "우선 순위",
    "Alphabetically" : "알파벳순",
    "Manually" : "수동으로",
    "Load remaining completed tasks." : "남아 있는 완료된 작업을 불러옵니다.",
    "All day" : "하루 종일",
    "(New category)" : "(새 분류)",
    "Select categories..." : "분류 선택...",
    "Loading the task..." : "작업 불러오는 중...",
    "Task not found!" : "작업을 찾을 수 없습니다!",
    "add a subtask to" : "다음에 하위 작업 추가"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ko.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "작업",
    "Due yesterday" : "어제 끝남",
    "Due today" : "오늘 끝남",
    "Due tomorrow" : "내일 끝남",
    "Due on" : "만료일:",
    "Started yesterday" : "어제 시작됨",
    "Starts today" : "오늘 시작됨",
    "Starts tomorrow" : "내일 시작됨",
    "Started on" : "시작일:",
    "Starts on" : "시작일:",
    "[Remind me yesterday at ]HH:mm" : "어제 HH:mm[에 알림]",
    "[Remind me today at ]HH:mm" : "오늘 HH:mm[에 알림]",
    "[Remind me tomorrow at ]HH:mm" : "내일 HH:mm[에 알림]",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "YYYY년 MMM DD일 HH:mm[에 알림]",
    "Yesterday" : "어제",
    "Today" : "오늘",
    "Tomorrow" : "내일",
    "in %s" : "%s",
    "%s ago" : "%s 전",
    "seconds" : "초",
    "a minute" : "1분",
    "%d minutes" : "%d분",
    "an hour" : "1시간",
    "%d hours" : "%d시간",
    "a day" : "1일",
    "%d days" : "%d일",
    "a month" : "1개월",
    "%d months" : "%d개월",
    "a year" : "1년",
    "%d years" : "%d년",
    "week" : "주",
    "weeks" : "주",
    "day" : "일",
    "days" : "일",
    "hour" : "시간",
    "hours" : "시간",
    "minute" : "분",
    "minutes" : "분",
    "second" : "초",
    "before beginning" : "시작 이전",
    "after beginning" : "시작 이후",
    "before end" : "종료 이전",
    "after end" : "종료 이후",
    "Comment" : "설명",
    "Add a comment" : "설명 추가",
    "This will delete the Calendar \"%s\" and all of its entries." : "달력 \"%s\" 및 포함된 모든 항목을 삭제합니다.",
    "The name \"%s\" is already used." : "이름 \"%s\"이(가) 이미 사용 중입니다.",
    "An empty name is not allowed." : "이름을 비워둘 수 없습니다.",
    "Hidden" : "숨김",
    "Visible" : "보임",
    "Automatic" : "자동",
    "Sunday" : "일요일",
    "Monday" : "월요일",
    "Tuesday" : "화요일",
    "Wednesday" : "수요일",
    "Thursday" : "목요일",
    "Friday" : "금요일",
    "Saturday" : "토요일",
    "Add an important item in \"%s\"..." : "\"%s\"에 중요한 항목 추가 중...",
    "Add an item due today in \"%s\"..." : "\"%s\"에 오늘 끝나는 항목 추가 중...",
    "Add an item in \"%s\"..." : "\"%s\"에 항목 추가 중...",
    "Add a current item in \"%s\"..." : "\"%s\"에 현재 항목 추가 중...",
    "Add a subtask to \"%s\"..." : "\"%s\"에 하위 작업 추가...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["완료된 작업 %n개"],
    "Hours" : "시간",
    "Minutes" : "분",
    "Set due date" : "만료 기한 설정",
    "%s %% completed" : "%s%% 완료됨",
    "priority %s: " : "%s 우선 순위: ",
    "high" : "높음",
    "medium" : "중간",
    "low" : "낮음",
    "no priority assigned" : "지정되지 않음",
    "Remind me" : "알림",
    "at the end" : "끝날 때",
    "at the beginning" : "시작할 때",
    "Set start date" : "시작 날짜 지점",
    "{calendar} shared by {owner}" : "{owner} 님이 공유한 달력",
    "Unnamed" : "이름 없음",
    "Important" : "중요",
    "Week" : "주",
    "All" : "모두",
    "Current" : "현재",
    "Completed" : "완료됨",
    "Delete" : "삭제",
    "Cancel" : "취소",
    "Edit" : "편집",
    "Link" : "링크",
    "Download" : "다운로드",
    "Save" : "저장",
    "Add List..." : "목록 추가...",
    "New List" : "새 목록",
    "Settings" : "설정",
    "Start of week" : "주의 첫 요일",
    "Visibility of Smart Collections" : "똑똑한 모음집 표시 여부",
    "Change sort order" : "정렬 순서 변경",
    "Default" : "기본값",
    "Due date" : "마감 날짜",
    "Start date" : "시작 날짜",
    "Priority" : "우선 순위",
    "Alphabetically" : "가나다순",
    "Manually" : "수동으로",
    "Load remaining completed tasks." : "남아 있는 완료된 작업을 불러옵니다.",
    "Task is completed" : "작업이 완료됨",
    "All day" : "하루 종일",
    "(New category)" : "(새 분류)",
    "Select categories..." : "분류 선택...",
    "Loading the task..." : "작업 불러오는 중...",
    "Task not found!" : "작업을 찾을 수 없습니다!",
    "add a subtask to" : "다음에 하위 작업 추가",
    "Toggle subtasks" : "하위 작업 전환",
    "Toggle completed subtasks" : "완료된 하위 작업 전환"
},
"nplurals=1; plural=0;");
